@@ -5,5 +5,5 @@ ${RPROG:-R} --vanilla <<EOF > ${OUT:-/dev/null} 2>&1
 library(Rmpi)
 library(snow)
 
-runMPIslave()
+runMPIworker()
 EOF
